@@ -2,7 +2,7 @@
 
 __author__ = """Damian Świstowski"""
 __email__ = "damian@swistowski.org"
-__version__ = "0.1.2"
+__version__ = "0.1.6"
 
 from .svarog import Svarog
 
@@ -11,4 +11,4 @@ default_builder = Svarog()
 forge = default_builder.forge
 register_forge = default_builder.register_forge
 
-__all__ = "forge"
+__all__ = ["forge"]
